import json
import requests
import time
import random
import snowflake.connector

END_POINT_URL = 'https://api.snowly.io/v1'

WAIT_A_SEC = random.randint(0, 50)


def run(token='', accounts=[]):


    time.sleep(WAIT_A_SEC)
    # alerts_res = requests.post(url=END_POINT_URL) #GET ALERTS
    alerts=[ {"alert_id":"guid","commands": [{"id":"warehouses","sql":"show warehouses; "},{"id":"roles","sql":"show roles "} ]} ]

    for alert in alerts:
        send_obj={}
        for command in alert['commands']:
            for account in accounts:

                # Connecting to Snowflake using the default authenticator
                cnx = snowflake.connector.connect(
                    account=account['host'],
                    user=account['user'],
                    password=account['password']
                )

                #Get Queries
                sql = command['sql']

                cur_res = cnx.cursor().execute(sql)

                send_obj={}

                rows=[]
                for  val in cur_res:
                    row_obj={}
                    for idx,col in enumerate(cur_res._description):
                        row_obj[col[0]] = val[idx]
                    rows.append(row_obj)

                send_obj[command['id']]= rows

        # alerts_res = requests.post(url=END_POINT_URL) #GET ALERTS
        print(send_obj)


if __name__ == '__main__':


    accounts = [{"host": "account.region", "display_name": "info", "user": "john", "password": "**"}]

    run('<YOUR_API_TOKEN>', accounts)



from distutils.core import setup
setup(
  name = 'pysnowly',
  packages = ['pysnowly'],
  version = '0.1',
  license='MIT',
  description = 'Ilan Z., Elad S.',   # Give a short description about your library
  author = 'Ilan Z., Elad S.',                   # Type in your name
  author_email = 'info@snowly.io',      # Type in your E-Mail
  url = 'https://github.com/user/pysnowly',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/snowly-io/pysnowly/archive/v_01.tar.gz',
  keywords = ['Snowly Trigger'],
  install_requires=[            # I get to this in a second
          'snowflake-connector-python',
          'requests',
      ],
  classifiers=[
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)